You are viewing a plain text version of this content. The canonical link for it is here.
Posted to github@datafusion.apache.org by "andygrove (via GitHub)" <gi...@apache.org> on 2026/07/15 17:54:08 UTC
Re: [PR] perf: optimize `cast_binary_to_string` binary-format styles (up to 27x faster) [datafusion-comet]
andygrove commented on PR #4912:
URL: https://github.com/apache/datafusion-comet/pull/4912#issuecomment-4983708281
> Looks like this PR will maybe conflict with #4763. Agree we should merge #4763 first.
https://github.com/apache/datafusion-comet/pull/4763 is merged, and this PR has been upmerged.
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org
For queries about this service, please contact Infrastructure at:
users@infra.apache.org
---------------------------------------------------------------------
To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org
For additional commands, e-mail: github-help@datafusion.apache.org